<?php

// Configuración
$dir = '/ruta/al/directorio'; // Directorio a procesar
$maxWidth = 1920; // Ancho máximo
$maxHeight = 1080; // Alto máximo
$jpegQuality = 78; // Calidad JPEG (0-100)
$pngCompression = 9; // Nivel de compresión PNG (0-9)
$processAllImages = false; // Establecer en true para procesar todas las imágenes, false para procesar solo las que exceden las dimensiones máximas

// Función para optimizar una imagen
function optimizeImage($file) {
    global $maxWidth, $maxHeight, $jpegQuality, $pngCompression, $processAllImages;

    $image = new Imagick($file);
    $origWidth = $image->getImageWidth();
    $origHeight = $image->getImageHeight();

    $needsRescaling = ($origWidth > $maxWidth || $origHeight > $maxHeight);

    if ($needsRescaling || $processAllImages) {
        // Redimensionar si excede las dimensiones máximas
        if ($needsRescaling) {
            $image->resizeImage($maxWidth, $maxHeight, Imagick::FILTER_LANCZOS, 1, true);
        }

        // Optimizar según el tipo de imagen
        $format = strtolower($image->getImageFormat());
        if ($format === 'jpeg' || $format === 'jpg') {
            $image->setImageCompression(Imagick::COMPRESSION_JPEG);
            $image->setImageCompressionQuality($jpegQuality);
        } elseif ($format === 'png') {
            $image->setImageCompression(Imagick::COMPRESSION_ZIP);
            $image->setImageCompressionQuality($pngCompression * 10); // Imagick usa escala 0-100
        }

        // Guardar la imagen optimizada
        $image->writeImage($file);
        echo "Imagen procesada: " . $file . PHP_EOL;
    } else {
        echo "Imagen no procesada (dimensiones dentro de los límites): " . $file . PHP_EOL;
    }

    $image->clear();
}

// Función para procesar un directorio recursivamente
function processDirectory($dir) {
    $files = new RecursiveIteratorIterator(
        new RecursiveDirectoryIterator($dir, RecursiveDirectoryIterator::SKIP_DOTS),
        RecursiveIteratorIterator::SELF_FIRST
    );

    foreach ($files as $file) {
        if ($file->isFile()) {
            $extension = strtolower($file->getExtension());
            if (in_array($extension, ['jpg', 'jpeg', 'png'])) {
                optimizeImage($file->getPathname());
            }
        }
    }
}

// Ejecutar el proceso
processDirectory($dir);

echo "Proceso completado." . PHP_EOL;
